@@ -18,6 +18,7 @@ import functools
 import json
 from multiprocessing.pool import ThreadPool
 import os
+import re
 import shlex
 import time
 
@@ -47,7 +48,7 @@ WARN_BIOSDEVNAME_NOT_FOUND = False
 UNIT_CONVERTER = pint.UnitRegistry(filename=None)
 UNIT_CONVERTER.define('bytes = []')
 UNIT_CONVERTER.define('MB = 1048576 bytes')
-
+_MEMORY_ID_RE = re.compile(r'^memory(:\d+)?$')
 NODE = None
 
 
@@ -757,11 +758,13 @@ class GenericHardwareManager(HardwareManager):
             for sys_child in sys_dict['children']:
                 if sys_child['id'] == 'core':
                     for core_child in sys_child['children']:
-                        if core_child['id'] == 'memory':
-                            if core_child.get('size'):
-                                value = "%(size)s %(units)s" % core_child
-                                physical += int(UNIT_CONVERTER(value).to(
-                                    'MB').magnitude)
+                        if _MEMORY_ID_RE.match(core_child['id']):
+                            for bank in core_child.get('children', ()):
+                                if bank.get('size'):
+                                    value = ("%(size)s %(units)s" % bank)
+                                    physical += int(UNIT_CONVERTER(value).to
+                                                    ('MB').magnitude)
+
             if not physical:
                 LOG.warning('Did not find any physical RAM')
 
@@ -1108,9 +1111,10 @@ class GenericHardwareManager(HardwareManager):
         utils.try_execute('modprobe', 'ipmi_si')
 
         try:
-            # From all the channels 0-15, only 1-7 can be assigned to different
-            # types of communication media and protocols and effectively used
-            for channel in range(1, 8):
+            # From all the channels 0-15, only 1-11 can be assigned to
+            # different types of communication media and protocols and
+            # effectively used
+            for channel in range(1, 12):
                 out, e = utils.execute(
                     "ipmitool lan print {} | awk '/IP Address[ \\t]*:/"
                     " {{print $4}}'".format(channel), shell=True)
